@@ -13,11 +13,13 @@
 #include "patchlevel.h"
 #include <stdlib.h>
 #include <X11/keysym.h>
+#include <pwd.h>
+#include <sys/types.h>
 
 char    *version[] = 
 {
     "9wm version 1.1, Copyright (c) 1994 David Hogan", 
-    "w9wm version 0.4.1, Copyright (c) 2000 Benjamin Drieu", 0,
+    "w9wm version 0.4.2, Copyright (c) 2000-2003 Benjamin Drieu", 0,
 };
 
 Display         *dpy;
@@ -45,6 +47,7 @@ int             signalled;
 Bool 		click_passes = 0;
 Bool		use_keys = 1;
 int		numvirtuals = 4;
+char *		progsnames[16];
 
 Atom        exit_9wm;
 Atom        restart_9wm;
@@ -146,6 +149,8 @@ char    *argv[];
     if (shell == NULL)
         shell = DEFSHELL;
 
+    parseprogsfile();
+
     dpy = XOpenDisplay(display);
     if (dpy == 0)
         fatal("can't open display");
@@ -886,3 +891,39 @@ XEvent *e;
     fprintf(stderr, "9wm: exiting on signal\n");
     exit(1);
 }
+
+
+void
+parseprogsfile ()
+{
+  FILE *file;
+  int i;
+  struct passwd * p = getpwuid(getuid());
+  char * buffer;
+
+  buffer = (char *) malloc (1024);
+  snprintf (buffer, 1024, "%s/.w9wmrc", p->pw_dir);
+
+  file = fopen (buffer, "r");
+  if (! file)
+    {
+      fprintf (stderr, "cannot open %s\n", buffer);
+      progsnames[0] = NULL;
+      return;
+    }
+
+  for (i = 0; i<16 && ! feof(file); i++)
+    {
+      buffer = (char *) malloc (1024);
+      if (! fgets(buffer, 1024, file))
+	break;
+      if (buffer[strlen(buffer)-1] == '\n')
+	buffer[strlen(buffer)-1] = 0;
+      progsnames[i] = buffer;
+    }
+
+  progsnames[i] = NULL;
+
+  fclose (file);
+  return;
+}
