@@ -1,5 +1,7 @@
 /* Copyright (c) 1994 David Hogan, 2000 Benjamin Drieu see README for licence details */
 #include <stdio.h>
+#include <malloc.h>
+#include <string.h>
 #include <X11/X.h>
 #include <X11/Xlib.h>
 #include <X11/Xutil.h>
@@ -8,7 +10,7 @@
 #include "fns.h"
 
 Client      *clients;
-Client      *current;
+Client      *current = NULL;	/* paranoid */
 
 void
 setactive(c, on)
@@ -19,10 +21,17 @@ int on;
         XUngrabButton(dpy, AnyButton, AnyModifier, c->parent);
 	XSetInputFocus(dpy, c->window, RevertToPointerRoot, timestamp()); 
 
-	XGrabKey(dpy, 
-		 XKeysymToKeycode(dpy, XK_Tab),
-		 ControlMask, 
-		 root, False, GrabModeAsync, GrabModeAsync);
+	if (use_keys)
+	  {
+	    XGrabKey(dpy, 
+		     XKeysymToKeycode(dpy, XK_Tab),
+		     ControlMask, 
+		     root, False, GrabModeAsync, GrabModeAsync);
+	    XGrabKey(dpy, 
+		     XKeysymToKeycode(dpy, XK_Tab),
+		     ControlMask|ShiftMask, 
+		     root, False, GrabModeAsync, GrabModeAsync);
+	  }
 
         if (c->proto & Ptakefocus)
             sendcmessage(c->window, wm_protocols, wm_take_focus);
